# modified from the python library faker:
# https://github.com/joke2k/faker/blob/master/faker/providers/lorem/ru_RU/__init__.py

lorem_word_list_ru_ru <- c(
  "\u0432\u043e\u0439\u0442\u0438",
  "\u043c\u043e\u043d\u0435\u0442\u0430",
  "\u0432\u0441\u043a\u0438\u043d\u0443\u0442\u044c",
  "\u0436\u0435\u043b\u0430\u043d\u0438\u0435",
  "\u044d\u043a\u0437\u0430\u043c\u0435\u043d",
  "\u043d\u0430\u043b\u043e\u0433\u043e\u0432\u044b\u0439",
  "\u0432\u044b\u0442\u0430\u0441\u043a\u0438\u0432\u0430\u0442\u044c",
  "\u043f\u0440\u0438\u044f\u0442\u0435\u043b\u044c",
  "\u0432\u0437\u0434\u0440\u0430\u0433\u0438\u0432\u0430\u0442\u044c",
  "\u043a\u0443\u0447\u0430",
  "\u043f\u043e\u0440\u0442",
  "\u0442\u043e\u0447\u043d\u043e",
  "\u0437\u0430\u043f\u043b\u0430\u043a\u0430\u0442\u044c",
  "\u0438\u0437\u0431\u0430",
  "\u043f\u0440\u0430\u0432\u043b\u0435\u043d\u0438\u0435",
  "\u0445\u0443\u0434\u043e\u0436\u0435\u0441\u0442\u0432\u0435\u043d\u043d\u044b\u0439",
  "\u043c\u0443\u0447\u0438\u0442\u0435\u043b\u044c\u043d\u043e",
  "\u0438\u0437\u043e\u0431\u0440\u0430\u0436\u0430\u0442\u044c",
  "\u0444\u043e\u043d\u0430\u0440\u0438\u043a",
  "\u043c\u0438\u0444",
  "\u0433\u0440\u0443\u0441\u0442\u043d\u044b\u0439",
  "\u043e\u043f\u0430\u0441\u043d\u043e\u0441\u0442\u044c",
  "\u043c\u0435\u0440\u0430",
  "\u043f\u0430\u0441\u0442\u0443\u0445",
  "\u0444\u0430\u043a\u0443\u043b\u044c\u0442\u0435\u0442",
  "\u043c\u0435\u043b\u044c\u043a\u043d\u0443\u0442\u044c",
  "\u043f\u043e\u043b\u0435\u0432\u043e\u0439",
  "\u0434\u0440\u0443\u0433\u043e\u0439",
  "\u0432\u044b\u0440\u0430\u0436\u0435\u043d\u043d\u044b\u0439",
  "\u0437\u0430\u0431\u0438\u0440\u0430\u0442\u044c",
  "\u0440\u043e\u0442",
  "\u043d\u0430\u0440\u043e\u0434",
  "\u0441\u043e\u043e\u0442\u0432\u0435\u0442\u0441\u0442\u0432\u0438\u0435",
  "\u0442\u0443\u0442\u0430",
  "\u043a\u043e\u043c\u043c\u0443\u043d\u0438\u0437\u043c",
  "\u0440\u0435\u0448\u0435\u043d\u0438\u0435",
  "\u043f\u043b\u043e\u0434",
  "\u0441\u043e\u0431\u0435\u0441\u0435\u0434\u043d\u0438\u043a",
  "\u0432\u043e\u0437\u043c\u0443\u0442\u0438\u0442\u044c\u0441\u044f",
  "\u0434\u043e\u0441\u0442\u043e\u0438\u043d\u0441\u0442\u0432\u043e",
  "\u0433\u043e\u0441\u043f\u043e\u0434\u044c",
  "\u0431\u043e\u043b\u043e\u0442\u043e",
  "\u0438\u043d\u0444\u0435\u043a\u0446\u0438\u044f",
  "\u0433\u043e\u043b\u0443\u0431\u0447\u0438\u043a",
  "\u0441\u044b\u043d\u043e\u043a",
  "\u043f\u0440\u043e\u0441\u0442\u0440\u0430\u043d\u0441\u0442\u0432\u043e",
  "\u043f\u0440\u043e\u0449\u0435\u043d\u0438\u0435",
  "\u043f\u0440\u0435\u0436\u0434\u0435",
  "\u0445\u043e\u0442\u0435\u0442\u044c",
  "\u043b\u0435\u043d\u0438\u043d\u0433\u0440\u0430\u0434",
  "\u0434\u0430\u043b\u044c",
  "\u0440\u0430\u0437\u0432\u0438\u0442\u044b\u0439",
  "\u0431\u043b\u0438\u0437\u043a\u043e",
  "\u0431\u043e\u043b\u0435\u0435",
  "\u0441\u043f\u043e\u0440\u0442",
  "\u044d\u043f\u043e\u0445\u0430",
  "\u043e\u0442\u0432\u0435\u0442\u0438\u0442\u044c",
  "\u043e\u0441\u0432\u043e\u0431\u043e\u0434\u0438\u0442\u044c",
  "\u0441\u043e\u0432\u0435\u0442",
  "\u043f\u0440\u043e\u0445\u043e\u0434",
  "\u043f\u0430\u043b\u0435\u0446",
  "\u0432\u0447\u0435\u0440\u0430",
  "\u043f\u0440\u0438\u043b\u0438\u0447\u043d\u044b\u0439",
  "\u044f\u0440\u043a\u043e",
  "\u0431\u0435\u043b\u044c\u0435",
  "\u043a\u0443\u0437\u043d\u0435\u0446",
  "\u043d\u0435\u043e\u0436\u0438\u0434\u0430\u043d\u043d\u043e",
  "\u0432\u043f\u0435\u0440\u0435\u0434",
  "\u0437\u0430\u0442\u043e",
  "\u043a\u043e\u043b\u044c\u0446\u043e",
  "\u043f\u0435\u0440\u0435\u0434\u043e",
  "\u043c\u0433\u043d\u043e\u0432\u0435\u043d\u0438\u0435",
  "\u043f\u043b\u0430\u0432\u043d\u043e",
  "\u0442\u0430\u0431\u0430\u043a",
  "\u0447\u0438\u0441\u043b\u043e",
  "\u0438\u0437\u0443\u0447\u0438\u0442\u044c",
  "\u0442\u044f\u0436\u0435\u043b\u044b\u0439",
  "\u0440\u0430\u0441\u0441\u0443\u0436\u0434\u0435\u043d\u0438\u0435",
  "\u0441\u0430\u043b\u043e\u043d",
  "\u0438\u0434\u0435\u044f",
  "\u0447\u0442\u043e",
  "\u0441\u0432\u0435\u0442\u0438\u043b\u043e",
  "\u043f\u043e\u0440\u043e\u0434\u0430",
  "\u0441\u043e\u043c\u043d\u0438\u0442\u0435\u043b\u044c\u043d\u044b\u0439",
  "\u0431\u043e\u043a",
  "\u043e\u0447\u043a\u043e",
  "\u043d\u0435\u0443\u0434\u043e\u0431\u043d\u043e",
  "\u0441\u043e\u0432\u0435\u0442\u043e\u0432\u0430\u0442\u044c",
  "\u043e\u0442\u0434\u0435\u043b",
  "\u043f\u043e\u043c\u043e\u043b\u0447\u0430\u0442\u044c",
  "\u043f\u043e\u0437\u0434\u0440\u0430\u0432\u043b\u044f\u0442\u044c",
  "\u043f\u0440\u043e\u0431\u043e\u0432\u0430\u0442\u044c",
  "\u0434\u043e\u0448\u043b\u044b\u0439",
  "\u0441\u043c\u0435\u044f\u0442\u044c\u0441\u044f",
  "\u0443\u043f\u043e\u0440\u043d\u043e",
  "\u0432\u0437\u0434\u0440\u043e\u0433\u043d\u0443\u0442\u044c",
  "\u0437\u0430\u0442\u044f\u043d\u0443\u0442\u044c\u0441\u044f",
  "\u0442\u0430\u043d\u0446\u0435\u0432\u0430\u0442\u044c",
  "\u043f\u0435\u0441\u0435\u043d\u043a\u0430",
  "\u0432\u044b\u0431\u0438\u0440\u0430\u0442\u044c",
  "\u043f\u0440\u0430\u0432\u0438\u043b\u044c\u043d\u044b\u0439",
  "\u043d\u0430\u043c\u0435\u0440\u0435\u043d\u0438\u0435",
  "\u0438\u0437\u0434\u0430\u043b\u0438",
  "\u0437\u0430\u043f\u0443\u0441\u0442\u0438\u0442\u044c",
  "\u043d\u0430\u0441\u043b\u0430\u0436\u0434\u0435\u043d\u0438\u0435",
  "\u043a\u0440\u044b\u0441\u0430",
  "\u043b\u0435\u0442\u0435\u0442\u044c",
  "\u043a\u043e\u0441\u043c\u043e\u0441",
  "\u0440\u0430\u0434\u043e\u0441\u0442\u044c",
  "\u043f\u043e\u0435\u0437\u0434",
  "\u043d\u0430\u0445\u043e\u0434\u0438\u0442\u044c",
  "\u0433\u0443\u043b\u044f\u0442\u044c",
  "\u0433\u043e\u0440\u044c\u043a\u0438\u0439",
  "\u0431\u043e\u0447\u043e\u043a",
  "\u043d\u043e\u0447\u044c",
  "\u0441\u0447\u0430\u0441\u0442\u044c\u0435",
  "\u0443\u043d\u0438\u0447\u0442\u043e\u0436\u0435\u043d\u0438\u0435",
  "\u0434\u044c\u044f\u0432\u043e\u043b",
  "\u043a\u043e\u0440\u043e\u0431\u043a\u0430",
  "\u0441\u043f\u0430\u0441\u0442\u044c",
  "\u043a\u043e\u0436\u0430",
  "\u043f\u0440\u043e\u0432\u0438\u043d\u0446\u0438\u044f",
  "\u043f\u0440\u0435\u043b\u0435\u0441\u0442\u044c",
  "\u0442\u044e\u0440\u044c\u043c\u0430",
  "\u043d\u0438\u0437\u043a\u0438\u0439",
  "\u0441\u0432\u0435\u0440\u043a\u0430\u0442\u044c",
  "\u0442\u0435\u043c\u043d\u0435\u0442\u044c",
  "\u0441\u043e\u043b\u043d\u0446\u0435",
  "\u0434\u0440\u0443\u0436\u043d\u043e",
  "\u043d\u0430\u0441\u0442\u0430\u0442\u044c",
  "\u0431\u043b\u0438\u043d",
  "\u0441\u0442\u0435\u043f\u044c",
  "\u0441\u0430\u043c\u043e\u0441\u0442\u043e\u044f\u0442\u0435\u043b\u044c\u043d\u043e",
  "\u043a\u0440\u0443\u0442\u043e\u0439",
  "\u043a\u0430\u0440\u0442\u0438\u043d\u043a\u0430",
  "\u0437\u0430\u0447\u0435\u043c",
  "\u0440\u0430\u0431\u043e\u0447\u0438\u0439",
  "\u043d\u0435\u043e\u0431\u044b\u0447\u043d\u044b\u0439",
  "\u0430\u0440\u043c\u0435\u0439\u0441\u043a\u0438\u0439",
  "\u0442\u0440\u0443\u043f",
  "\u044f\u0433\u043e\u0434\u0430",
  "\u043e\u043a\u043e\u043b\u043e",
  "\u043c\u043e\u043d\u0435\u0442\u0430",
  "\u0435\u0441\u0442\u0435\u0441\u0442\u0432\u0435\u043d\u043d\u044b\u0439",
  "\u044e\u043d\u044b\u0439",
  "\u0440\u0430\u0439\u043e\u043d",
  "\u0441\u043a\u0440\u044b\u0442\u044b\u0439",
  "\u043f\u043e\u0439\u043c\u0430\u0442\u044c",
  "\u0441\u0442\u0440\u043e\u0438\u0442\u0435\u043b\u044c\u0441\u0442\u0432\u043e",
  "\u043f\u0430\u043b\u0430\u0442\u0430",
  "\u043c\u0438\u0433",
  "\u0442\u0440\u0438\u0441\u0442\u0430",
  "\u0448\u0442\u0430\u0431",
  "\u043b\u043e\u043c\u0430\u0442\u044c",
  "\u0432\u043e\u0437\u043c\u043e\u0436\u043d\u043e",
  "\u043f\u043e\u043b\u044e\u0431\u0438\u0442\u044c",
  "\u0447\u0435\u043b\u043e\u0432\u0435\u0447\u0435\u043a",
  "\u043b\u0435\u0433\u043a\u043e",
  "\u0447\u0443\u0432\u0441\u0442\u0432\u043e",
  "\u0440\u0443\u0447\u0435\u0439",
  "\u043a\u0430\u0440\u043c\u0430\u043d",
  "\u0434\u0435\u043d\u044c\u0433\u0438",
  "\u043d\u0435\u043f\u0440\u0430\u0432\u0434\u0430",
  "\u0441\u0440\u0430\u0432\u043d\u0435\u043d\u0438\u0435",
  "\u0433\u0440\u0443\u0434\u044c",
  "\u043e\u0442\u044a\u0435\u0437\u0434",
  "\u0432\u043e\u0437\u043d\u0438\u043a\u043d\u043e\u0432\u0435\u043d\u0438\u0435",
  "\u0441\u0442\u0435\u043f\u044c",
  "\u0432\u043e\u0437\u0431\u0443\u0436\u0434\u0435\u043d\u0438\u0435",
  "\u0434\u0435\u043b\u043e\u0432\u043e\u0439",
  "\u0441\u043b\u0435\u0434\u043e\u0432\u0430\u0442\u0435\u043b\u044c\u043d\u043e",
  "\u0436\u0438\u0434\u043a\u0438\u0439",
  "\u0441\u044b\u043d\u043e\u043a",
  "\u0445\u0443\u0434\u043e\u0436\u0435\u0441\u0442\u0432\u0435\u043d\u043d\u044b\u0439",
  "\u043f\u043e\u043a\u043e\u043b\u0435\u043d\u0438\u0435",
  "\u0440\u0430\u0441\u0441\u0442\u0435\u0433\u043d\u0443\u0442\u044c",
  "\u043f\u0438\u0449\u0430",
  "\u0443\u0447\u0435\u043d\u044b\u0439",
  "\u0441\u0435\u043a\u0443\u043d\u0434\u0430",
  "\u0443\u0441\u043f\u043e\u043a\u043e\u0438\u0442\u044c\u0441\u044f",
  "\u0432\u0440\u044f\u0434",
  "\u0430\u0436",
  "\u0432\u0441\u043a\u0430\u043a\u0438\u0432\u0430\u0442\u044c",
  "\u043c\u0438\u043c\u043e",
  "\u043f\u0430\u0434\u0430\u0442\u044c",
  "\u043f\u043e\u0442\u044f\u043d\u0443\u0442\u044c\u0441\u044f",
  "\u0443\u0433\u0440\u043e\u0437\u0430",
  "\u0440\u0430\u0441\u0442\u0435\u0440\u044f\u0442\u044c\u0441\u044f",
  "\u0431\u0435\u0433\u0430\u0442\u044c",
  "\u0441\u0442\u0430\u043a\u0430\u043d",
  "\u043e",
  "\u043a\u043f\u0441\u0441",
  "\u043d\u044b\u043d\u0435",
  "\u043f\u043e\u043b",
  "\u0440\u0435\u043a\u043b\u0430\u043c\u0430",
  "\u043f\u0440\u0438",
  "\u0448\u043a\u043e\u043b\u044c\u043d\u044b\u0439",
  "\u043f\u0440\u0435\u043c\u044c\u0435\u0440\u0430",
  "\u0434\u0430\u043b\u044c\u043d\u0438\u0439",
  "\u043f\u043e\u0442\u0440\u044f\u0441\u0442\u0438",
  "\u043e\u0441\u0432\u043e\u0431\u043e\u0436\u0434\u0435\u043d\u0438\u0435",
  "\u043f\u043e\u043a\u0438\u0434\u0430\u0442\u044c",
  "\u043d\u0430\u0441\u0442\u0443\u043f\u0430\u0442\u044c",
  "\u0436\u0438\u0442\u044c",
  "\u043a\u0430\u043a\u043e\u0439",
  "\u043e\u0431\u0438\u0434\u0430",
  "\u043a\u043e\u043c\u0430\u043d\u0434\u043e\u0432\u0430\u043d\u0438\u0435",
  "\u0434\u0435\u0432\u043a\u0430",
  "\u0432\u044b\u0440\u0430\u0436\u0430\u0442\u044c\u0441\u044f",
  "\u0433\u043e\u043b\u043e\u0432\u043d\u043e\u0439",
  "\u0432\u0442\u043e\u0440\u043e\u0439",
  "\u043a\u043d\u044f\u0437\u044c",
  "\u0441\u043e\u0446\u0438\u0430\u043b\u0438\u0441\u0442\u0438\u0447\u0435\u0441\u043a\u0438\u0439",
  "\u0433\u043e\u043b\u043e\u0432\u043a\u0430",
  "\u043f\u0440\u0438\u0432\u043b\u0435\u043a\u0430\u0442\u044c",
  "\u0447\u0435\u0440\u0435\u0437",
  "\u0433\u043e\u0441\u043f\u043e\u0434\u044c",
  "\u0440\u0435\u0437\u0443\u043b\u044c\u0442\u0430\u0442",
  "\u043e\u0442\u043c\u0435\u0442\u0438\u0442\u044c",
  "\u0432\u0435\u0434\u044c",
  "\u043f\u0430\u0434\u0430\u043b\u044c",
  "\u043f\u043e\u043a\u0438\u0434\u0430\u0442\u044c",
  "\u0445\u0443\u0434\u043e\u0436\u0435\u0441\u0442\u0432\u0435\u043d\u043d\u044b\u0439",
  "\u043f\u0440\u0430\u0432\u044b\u0439",
  "\u0432\u0438\u0441\u0435\u0442\u044c",
  "\u043b\u0430\u043f\u0430",
  "\u043a\u0430\u044e\u0442\u0430",
  "\u0441\u043b\u0438\u0448\u043a\u043e\u043c",
  "\u043d\u0435\u0440\u0432\u043d\u043e",
  "\u0441\u0435\u0440\u044c\u0435\u0437\u043d\u044b\u0439",
  "\u0437\u0438\u043c\u0430",
  "\u0437\u0430\u0440\u0430\u0431\u043e\u0442\u0430\u0442\u044c",
  "\u044d\u0444\u0444\u0435\u043a\u0442",
  "\u043f\u0440\u043e\u043f\u0430\u0441\u0442\u044c",
  "\u043f\u043b\u043e\u0434",
  "\u0447\u0442\u043e",
  "\u0432\u0438\u0441\u0435\u0442\u044c",
  "\u0445\u043e\u043b\u043e\u0434\u043d\u043e",
  "\u0435\u0434\u0438\u043d\u044b\u0439",
  "\u0432\u044b\u043a\u0438\u043d\u0443\u0442\u044c",
  "\u043c\u0440\u0430\u0447\u043d\u043e",
  "\u0432\u044b\u0433\u043d\u0430\u0442\u044c",
  "\u0443\u043c\u0438\u0440\u0430\u0442\u044c",
  "\u0438\u043d\u043e\u0439",
  "\u043a\u043e\u0441\u043c\u043e\u0441",
  "\u043f\u0440\u0438\u0440\u043e\u0434\u0430",
  "\u0444\u0443\u043d\u043a\u0446\u0438\u044f",
  "\u043f\u043e\u0441\u0442\u0430\u0432\u0438\u0442\u044c",
  "\u043e\u0431\u043e\u0440\u043e\u0442",
  "\u0443\u0441\u043b\u0430\u0442\u044c",
  "\u043e\u0447\u0435\u0440\u0435\u0434\u043d\u043e\u0439",
  "\u043c\u0435\u0434\u0438\u0446\u0438\u043d\u0430",
  "\u0444\u0443\u043d\u043a\u0446\u0438\u044f",
  "\u0437\u0430\u0440\u043f\u043b\u0430\u0442\u0430",
  "\u0432\u044b\u0434\u0435\u0440\u0436\u0430\u0442\u044c",
  "\u0440\u0430\u0441\u0441\u0442\u0440\u043e\u0439\u0441\u0442\u0432\u043e",
  "\u0430\u0434\u0432\u043e\u043a\u0430\u0442",
  "\u0437\u0430\u0434\u0435\u0440\u0436\u0430\u0442\u044c",
  "\u043f\u043e\u044f\u0432\u043b\u0435\u043d\u0438\u0435",
  "\u0438\u043d\u0432\u0430\u043b\u0438\u0434",
  "\u0438\u043d\u0442\u0435\u043b\u043b\u0435\u043a\u0442\u0443\u0430\u043b\u044c\u043d\u044b\u0439",
  "\u0438\u0441\u0441\u043b\u0435\u0434\u043e\u0432\u0430\u043d\u0438\u0435",
  "\u0433\u043e\u0441\u043f\u043e\u0434\u044c",
  "\u0441\u043c\u0435\u0440\u0442\u0435\u043b\u044c\u043d\u044b\u0439",
  "\u0441\u043f\u0438\u0447\u043a\u0430",
  "\u0432\u0430\u0440\u0438\u0430\u043d\u0442",
  "\u0440\u0430\u0439",
  "\u043e\u0434\u0438\u043d\u043d\u0430\u0434\u0446\u0430\u0442\u044c",
  "\u0447\u0435\u043c",
  "\u043c\u0430\u043d\u0435\u0440\u0430",
  "\u043c\u0430\u0433\u0430\u0437\u0438\u043d",
  "\u043f\u043e\u0433\u043e\u0432\u043e\u0440\u0438\u0442\u044c",
  "\u043f\u043e\u043b\u043e\u0441\u043a\u0430",
  "\u043f\u043e\u043c\u0438\u043c\u043e",
  "\u043f\u043e\u0441\u0442\u0440\u043e\u0438\u0442\u044c",
  "\u0434\u043e\u043c\u0430\u0448\u043d\u0438\u0439",
  "\u043c\u0435\u0445\u0430\u043d\u0438\u0447\u0435\u0441\u043a\u0438\u0439",
  "\u0441\u043e\u0445\u0440\u0430\u043d\u044f\u0442\u044c",
  "\u043e\u0442\u0440\u0430\u0436\u0435\u043d\u0438\u0435",
  "\u043d\u0430\u0443\u0447\u0438\u0442\u044c",
  "\u0442\u0435\u0441\u043d\u043e",
  "\u0430\u043b\u043b\u0435\u044f",
  "\u043f\u0440\u0435\u0436\u043d\u0438\u0439",
  "\u043f\u043e\u0441\u0438\u0434\u0435\u0442\u044c",
  "\u0441\u043b\u0430\u0432\u043d\u044b\u0439",
  "\u043e\u0447\u0443\u0442\u0438\u0442\u044c\u0441\u044f",
  "\u043b\u0435\u0442\u0435\u0442\u044c",
  "\u043d\u0435\u0432\u043e\u0437\u043c\u043e\u0436\u043d\u043e",
  "\u043f\u043e\u0440\u044f\u0434\u043e\u043a",
  "\u0432\u044b\u0440\u0430\u0437\u0438\u0442\u044c",
  "\u0441\u043f\u0435\u0448\u0438\u0442\u044c",
  "\u0441\u044b\u043d\u043e\u043a",
  "\u0440\u0435\u0431\u044f\u0442\u0438\u0448\u043a\u0438",
  "\u0443\u0433\u0440\u043e\u0437\u0430",
  "\u043e\u0441\u0442\u0430\u0432\u0438\u0442\u044c",
  "\u0446\u0432\u0435\u0442",
  "\u043d\u0430\u043b\u0435\u0432\u043e",
  "\u043f\u0430\u0440\u0435\u043d\u044c",
  "\u043c\u0438\u043b\u043b\u0438\u0430\u0440\u0434",
  "\u0433\u043e\u0440\u044c\u043a\u0438\u0439",
  "\u0442\u0440\u0443\u0431\u043a\u0430",
  "\u043f\u043e\u0434\u0440\u043e\u0431\u043d\u043e\u0441\u0442\u044c",
  "\u043f\u0430\u0441\u0442\u044c",
  "\u043d\u0435\u043f\u0440\u0438\u0432\u044b\u0447\u043d\u044b\u0439",
  "\u0443\u0433\u043e\u0434\u043d\u044b\u0439",
  "\u0437\u0430\u0441\u0443\u043d\u0443\u0442\u044c",
  "\u0446\u0435\u043b\u044c",
  "\u0437\u0430\u043f\u0440\u0435\u0442\u0438\u0442\u044c",
  "\u0434\u0440\u0435\u043c\u0430\u0442\u044c",
  "\u0440\u0430\u0437\u0443\u043c\u0435\u0442\u044c\u0441\u044f",
  "\u043f\u0440\u0438\u0445\u043e\u0434\u0438\u0442\u044c",
  "\u0441\u043e\u0432\u0435\u0449\u0430\u043d\u0438\u0435",
  "\u043f\u043e\u0441\u0442\u043e\u044f\u043d\u043d\u044b\u0439",
  "\u0430\u043d\u0430\u043b\u0438\u0437",
  "\u0442\u0435\u0440\u0430\u043f\u0438\u044f",
  "\u043f\u0440\u0438\u044f\u0442\u0435\u043b\u044c",
  "\u043f\u0440\u043e\u0446\u0435\u0441\u0441",
  "\u0430\u043a\u0430\u0434\u0435\u043c\u0438\u043a",
  "\u043c\u0435\u0442\u0430\u043b\u043b",
  "\u0440\u0430\u0437\u0432\u0435\u0440\u043d\u0443\u0442\u044c\u0441\u044f",
  "\u0436\u0435\u0441\u0442\u043e\u043a\u0438\u0439",
  "\u0438\u043d\u0442\u0435\u0440\u043d\u0435\u0442",
  "\u0431\u0430\u043d\u0434\u0430",
  "\u0438\u0437\u043c\u0435\u043d\u0435\u043d\u0438\u0435",
  "\u043a\u043e\u043b\u043b\u0435\u043a\u0442\u0438\u0432",
  "\u043f\u043e\u0445\u043e\u0440\u043e\u043d\u044b",
  "\u0443\u0441\u0442\u0440\u043e\u0439\u0441\u0442\u0432\u043e",
  "\u0442\u043e\u0440\u043e\u043f\u043b\u0438\u0432\u044b\u0439",
  "\u0440\u0430\u0437\u0432\u043e\u0434\u0438\u0442\u044c",
  "\u043f\u0440\u043e\u043c\u043e\u043b\u0447\u0430\u0442\u044c",
  "\u043f\u043e\u0434\u0437\u0435\u043c\u043d\u044b\u0439",
  "\u043f\u043b\u0430\u043c\u044f",
  "\u0440\u0435\u0434\u0430\u043a\u0442\u043e\u0440",
  "\u0442\u0435\u043e\u0440\u0438\u044f",
  "\u043a\u0430\u0440\u0430\u043d\u0434\u0430\u0448",
  "\u0443\u043f\u043e\u0440",
  "\u043e\u0437\u043d\u0430\u0447\u0430\u0442\u044c",
  "\u0431\u0430\u0431\u043e\u0447\u043a\u0430",
  "\u0447\u0435\u0442\u044b\u0440\u0435",
  "\u0441\u0442\u043e\u043b\u0435\u0442\u0438\u0435",
  "\u0440\u0430\u0437\u043d\u043e\u043e\u0431\u0440\u0430\u0437\u043d\u044b\u0439",
  "\u0432\u0438\u0442\u0440\u0438\u043d\u0430",
  "\u043d\u043e\u0436",
  "\u043a\u043e\u043c\u0430\u043d\u0434\u0430",
  "\u0448\u043b\u0435\u043c",
  "\u043d\u0435\u0434\u043e\u0441\u0442\u0430\u0442\u043e\u043a",
  "\u043f\u0440\u043e\u0442\u044f\u0433\u0438\u0432\u0430\u0442\u044c",
  "\u0437\u0430",
  "\u043c\u0435\u0442\u0430\u043b\u043b",
  "\u0434\u043e\u0431\u0438\u0442\u044c\u0441\u044f",
  "\u0441\u0443\u0442\u043a\u0438",
  "\u0447\u0435\u0442\u043a\u043e",
  "\u043f\u0440\u0435\u0434\u043e\u0441\u0442\u0430\u0432\u0438\u0442\u044c",
  "\u0442\u044b\u0441\u044f\u0447\u0430",
  "\u0437\u0430\u043f\u0435\u0442\u044c",
  "\u0431\u0440\u0438\u0433\u0430\u0434\u0430",
  "\u043c\u0435\u043b\u043e\u0447\u044c",
  "\u0432\u044b\u0440\u0430\u0436\u0435\u043d\u043d\u044b\u0439",
  "\u043f\u0435\u0440\u0435\u0441\u0435\u0447\u044c",
  "\u0441\u0445\u043e\u0434\u0438\u0442\u044c",
  "\u0432\u043e\u043e\u0431\u0449\u0435",
  "\u0440\u0438\u0441",
  "\u0431\u0430\u043d\u043a",
  "\u0431\u0430\u043a",
  "\u043f\u0435\u0440\u0435\u0434\u043e",
  "\u043d\u0430\u0437\u043d\u0430\u0447\u0438\u0442\u044c",
  "\u0432\u0430\u0436\u043d\u044b\u0439",
  "\u043f\u0440\u0430\u0432\u043b\u0435\u043d\u0438\u0435",
  "\u043f\u0430\u043b\u043a\u0430",
  "\u0442\u0440\u044f\u0441\u0442\u0438",
  "\u0443\u0440\u043e\u043d\u0438\u0442\u044c",
  "\u0432\u0438\u0442\u0440\u0438\u043d\u0430",
  "\u043e\u0441\u043d\u043e\u0432\u0430\u043d\u0438\u0435",
  "\u0434\u0430",
  "\u043f\u0435\u0440\u0435\u0431\u0438\u0432\u0430\u0442\u044c",
  "\u0434\u044b\u0445\u0430\u043d\u0438\u0435",
  "\u043f\u0440\u0438\u043c\u0435\u043d\u044f\u0442\u044c\u0441\u044f",
  "\u0438\u044e\u043d\u044c",
  "\u0431\u0435\u0442\u043e\u043d\u043d\u044b\u0439",
  "\u0438\u0437\u0431\u0435\u0433\u0430\u0442\u044c",
  "\u0443\u043c\u043e\u043b\u044f\u0442\u044c",
  "\u043c\u044f\u0433\u043a\u0438\u0439",
  "\u0437\u0430\u044f\u0432\u043b\u0435\u043d\u0438\u0435",
  "\u043a\u043e\u043d\u0444\u0435\u0440\u0435\u043d\u0446\u0438\u044f",
  "\u0432\u0441\u0442\u0430\u0442\u044c",
  "\u0441\u0432\u0435\u0436\u0438\u0439",
  "\u0441\u043e\u043f\u0440\u043e\u0432\u043e\u0436\u0434\u0430\u0442\u044c\u0441\u044f",
  "\u0446\u0435\u043f\u043e\u0447\u043a\u0430",
  "\u0432\u044b\u0440\u0430\u0436\u0435\u043d\u0438\u0435",
  "\u0443\u0433\u043e\u043b",
  "\u0431\u043e\u0442\u0438\u043d\u043e\u043a",
  "\u043b\u043e\u0436\u0438\u0442\u044c\u0441\u044f",
  "\u0438\u043d\u0441\u0442\u0440\u0443\u043a\u0446\u0438\u044f",
  "\u043f\u0440\u0438\u0441\u0435\u0441\u0442\u044c",
  "\u0440\u0435\u0448\u0435\u0442\u043a\u0430",
  "\u0435\u0432\u0440\u0435\u0439\u0441\u043a\u0438\u0439",
  "\u043f\u043e\u0440\u043e\u0433",
  "\u0437\u0435\u043b\u0435\u043d\u044b\u0439",
  "\u0433\u0440\u0430\u043d\u0438\u0446\u0430",
  "\u0441\u0442\u0430\u0432\u0438\u0442\u044c",
  "\u0441\u043c\u0435\u043b\u044b\u0439",
  "\u0441\u0443\u0441\u0442\u0430\u0432",
  "\u0440\u043e\u0441\u0430",
  "\u0434\u0435\u043c\u043e\u043a\u0440\u0430\u0442\u0438\u044f",
  "\u0432\u044b\u0432\u0435\u0441\u0442\u0438",
  "\u043a\u043e\u043d\u0441\u0442\u0440\u0443\u043a\u0446\u0438\u044f",
  "\u0437\u0430\u0434\u0440\u0430\u0442\u044c",
  "\u0431\u0430\u0433\u0440\u043e\u0432\u044b\u0439",
  "\u0432\u043e\u0435\u043d\u043d\u044b\u0439",
  "\u043d\u0430\u043f\u0440\u0430\u0432\u043e",
  "\u0436\u0438\u0442\u0435\u043b\u044c",
  "\u0442\u043e\u0432\u0430\u0440",
  "\u043d\u0435\u043f\u0440\u0430\u0432\u0434\u0430",
  "\u043c\u0430\u0442\u0435\u0440\u0438\u044f",
  "\u043a\u043e\u043c\u0430\u043d\u0434\u0443\u044e\u0449\u0438\u0439",
  "\u043a\u0438\u0434\u0430\u0442\u044c",
  "\u0437\u0430\u043b\u043e\u0436\u0438\u0442\u044c",
  "\u043b\u0438\u043b\u043e\u0432\u044b\u0439",
  "\u0441\u043b\u0430\u0442\u044c",
  "\u0433\u043e\u0440\u044c\u043a\u0438\u0439",
  "\u043f\u0440\u043e\u0441\u0442\u0440\u0430\u043d\u0441\u0442\u0432\u043e",
  "\u043f\u0440\u043e\u0432\u0430\u043b",
  "\u043c\u0443\u0441\u043e\u0440",
  "\u043d\u0430\u0442\u043a\u043d\u0443\u0442\u044c\u0441\u044f",
  "\u0442\u043e\u0440\u0433\u043e\u0432\u043b\u044f",
  "\u043c\u043e\u043d\u0435\u0442\u0430",
  "\u043c\u0435\u0441\u0442\u043e",
  "\u0441\u043f\u0430\u043b\u0438\u0442\u044c",
  "\u0431\u0440\u043e\u0432\u044c",
  "\u043b\u0435\u0432\u044b\u0439",
  "\u0445\u043b\u0435\u0431",
  "\u043a\u043e\u0440\u0438\u0447\u043d\u0435\u0432\u044b\u0439",
  "\u043f\u043e\u0442\u043e\u043c",
  "\u0441\u0442\u0440\u0430\u0441\u0442\u044c",
  "\u0432\u0438\u0434\u043d\u0435\u0442\u044c\u0441\u044f",
  "\u0440\u043e\u0441\u043a\u043e\u0448\u043d\u044b\u0439",
  "\u0441\u043f\u043e\u0441\u043e\u0431",
  "\u043a\u043e\u0441\u0442\u0435\u0440",
  "\u0437\u0430\u0432\u0435\u0434\u0435\u043d\u0438\u0435",
  "\u043f\u0440\u043e\u043f\u0430\u0434\u0430\u0442\u044c",
  "\u0441\u043b\u0438\u0448\u043a\u043e\u043c",
  "\u043f\u044f\u0442\u0435\u0440\u043e",
  "\u043c\u0430\u043b\u044c\u0447\u0438\u0448\u043a\u0430",
  "\u0442\u0443\u0441\u043a\u043b\u044b\u0439",
  "\u043d\u0435\u043e\u0436\u0438\u0434\u0430\u043d\u043d\u044b\u0439",
  "\u043f\u043b\u044f\u0441\u0430\u0442\u044c",
  "\u0434\u0443\u0440\u0430\u0446\u043a\u0438\u0439",
  "\u0434\u0440\u043e\u0433\u043d\u0443\u0442\u044c",
  "\u0441\u0431\u0440\u043e\u0441\u0438\u0442\u044c",
  "\u043f\u0440\u043e\u0448\u0435\u043f\u0442\u0430\u0442\u044c",
  "\u0431\u0435\u0441\u043f\u043e\u043c\u043e\u0449\u043d\u044b\u0439",
  "\u0440\u043e\u0442\u0430",
  "\u043f\u0435\u0441\u043d\u044f",
  "\u0442\u0440\u0435\u0432\u043e\u0433\u0430",
  "\u043d\u0435\u043a\u043e\u0442\u043e\u0440\u044b\u0439",
  "\u0442\u0435\u0440\u043c\u0438\u043d",
  "\u043d\u0430\u0436\u0430\u0442\u044c",
  "\u0432\u0438\u0434\u0438\u043c\u043e",
  "\u0432\u0430\u043b\u044e\u0442\u0430",
  "\u043d\u0430\u0431\u043e\u0440",
  "\u0431\u043e\u0435\u0446",
  "\u0440\u0430\u0439\u043a\u043e\u043c",
  "\u043d\u043e\u0432\u044b\u0439",
  "\u0441\u043a\u043e\u043b\u044c\u0437\u0438\u0442\u044c",
  "\u0440\u0443\u043a\u043e\u0432\u043e\u0434\u0438\u0442\u0435\u043b\u044c",
  "\u0432\u043e\u043b\u043a",
  "\u0438\u0437\u0440\u0435\u0434\u043a\u0430",
  "\u043f\u043e\u043d\u044f\u0442\u043d\u044b\u0439",
  "\u043f\u0440\u043e\u043f\u0430\u0433\u0430\u043d\u0434\u0430",
  "\u043e\u0441\u0442\u0430\u043d\u043e\u0432\u0438\u0442\u044c",
  "\u0438\u0441\u043f\u043e\u043b\u043d\u044f\u0442\u044c",
  "\u0445\u043e\u0434",
  "\u0433\u043e\u0441\u043f\u043e\u0436\u0430",
  "\u043f\u0435\u0447\u0430\u0442\u0430\u0442\u044c",
  "\u043a\u043e\u043c\u0430\u043d\u0434\u0438\u0440",
  "\u0441\u043d\u0438\u043c\u0430\u0442\u044c",
  "\u043a\u0430\u0437\u043d\u044c",
  "\u043d\u0435\u0432\u044b\u043d\u043e\u0441\u0438\u043c\u044b\u0439",
  "\u0441\u043f\u043e\u0440\u0442",
  "\u0442\u0440\u0435\u0432\u043e\u0433\u0430",
  "\u0443\u0442\u043e\u0447\u043d\u0438\u0442\u044c",
  "\u0430\u043a\u0442\u0440\u0438\u0441\u0430",
  "\u043f\u043e\u043b\u043d\u043e\u0441\u0442\u044c\u044e",
  "\u043f\u043e\u043a\u0438\u043d\u0443\u0442\u044c",
  "\u0441\u0432\u0435\u0440\u043a\u0430\u044e\u0449\u0438\u0439",
  "\u043c\u043e\u0442\u043e\u0446\u0438\u043a\u043b",
  "\u0434\u043e\u0440\u043e\u0433\u043e\u0439",
  "\u0443\u043a\u0430\u0437\u0430\u043d\u043d\u044b\u0439",
  "\u0440\u0435\u043c\u0435\u043d\u044c",
  "\u043f\u043e\u0441\u0432\u044f\u0442\u0438\u0442\u044c",
  "\u043e\u0434\u0438\u043d",
  "\u0430",
  "\u0434\u043e\u0441\u0442\u0430\u0432\u0430\u0442\u044c",
  "\u0445\u043e\u0437\u044f\u0439\u043a\u0430",
  "\u043d\u043e\u0441\u043e\u043a",
  "\u043d\u0430\u043f\u0438\u0441\u0430\u0442\u044c",
  "\u0435\u0432\u0440\u0435\u0439\u0441\u043a\u0438\u0439",
  "\u043f\u0440\u0438\u0437\u044b\u0432",
  "\u0443\u0432\u0435\u043b\u0438\u0447\u0438\u0432\u0430\u0442\u044c\u0441\u044f",
  "\u0440\u0430\u0432\u043d\u043e\u0434\u0443\u0448\u043d\u044b\u0439"
)

#' Lorem provider Russian (Russia)
#'
#' Methods for Lorem Ipsum generation.
#' Lorem Ipsum is a placeholder text commonly used to demonstrate the visual
#' form of a document or a typeface without relying on meaningful content.
#' @family ru
#' @family RU
#' @export
#' @examples
#' x <- LoremProvider_ru_RU$new()
#' x$word()
#' x$words(3)
#' x$words(6)
#' x$sentence()
#' x$paragraph()
#' x$paragraphs(3)
#' cat(x$paragraphs(6), sep = "\n")
#' x$text(19)
#' x <- LoremProvider_ru_RU$new(word_connector = " --- ")
#' x$paragraph(4)
LoremProvider_ru_RU <- R6::R6Class(
  inherit = LoremProvider,
  "LoremProvider_ru_RU",
  private = list(
    word_list = lorem_word_list_ru_ru,
    locale_ = "ru_RU"
  )
)
